package CIF::WebAPI::malware;
use base 'CIF::WebAPI';

use warnings;
use strict;

sub buildNext {
    my ($self,$frag,$req) = @_;
    $frag = lc($frag);
    
    if($frag =~ /^[0-9a-f]{32,40}$/){
        $self->{'query'} = $frag;
        return $self;
    } else {
        return $self->SUPER::buildNext($frag,$req);
    }
}

1;
